/*
 *
 * IBM Confidential
 *
 * OCO Source Materials
 *
 * 5724-U18
 *
 * (C) COPYRIGHT IBM CORP. 2011,2014
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 *
 */
package psdi.iface.webservices;

import java.rmi.RemoteException;

import com.ibm.tivoli.maximo.intservice.WebMethodService;

import psdi.iface.action.MAXActionServiceLocal;
import psdi.iface.action.MAXActionServiceRemote;
import psdi.iface.mic.MicConstants;
import psdi.iface.util.SecurityUtil;
import psdi.util.MXApplicationException;
import psdi.util.MXException;

/**
 * Web service proxy for the standard services.
 * @author Anamitra
 *
 */
public class ActionWebServiceProxy extends BaseWebServiceProxy
{

	/* (non-Javadoc)
	 * @see psdi.iface.webservices.BaseServiceProxy#getEJBLocalRefName()
	 */
	@Override
	protected String getEJBLocalRefName() 
	{
		return MicConstants.ACTION_EJB_LOCAL_REF_KEY;
	}

	/* (non-Javadoc)
	 * @see psdi.iface.webservices.BaseServiceProxy#getEJBRemoteRefName()
	 */
	@Override
	protected String getEJBRemoteRefName() 
	{
		return MicConstants.ACTION_EJB_REF_KEY;
	}

	/* (non-Javadoc)
	 * @see psdi.iface.webservices.BaseServiceProxy#invokeService(java.lang.String, java.lang.String, byte[])
	 */
	@Override
	protected byte[] invokeService(String loginid, String password, byte[] req)
			throws MXException, RemoteException 
	{
        byte[] response = null;
        Object ejbObject = getEJBObject();
        getLogger().debug("ActionWebServiceProvider - Got the EJB handle "+ejbObject);
        if (req == null || req.length == 0) // sanity check
        {
            throw new MXApplicationException("iface", "servlet_no_xmldata");
        }
        
        boolean allowDfltLogin = SecurityUtil.isAllowDefaultLogin();

        if(isUseAppServerSecurity())
        {
            getLogger().debug("ActionWebServiceProvider - app server security turned on");

            if(SecurityUtil.APIKEYLOGIN.equals(loginid))
        	{
        		String apikey = password;
        		WebMethodService service = new WebMethodService();
        		response = service.wsMaxAPIKeySecureAction(apikey, req, serviceName);
        	}
        	else
        	{
	            if(allowDfltLogin)
	            {
	            	WebMethodService service = new WebMethodService();
	            	response = service.wsAction(req, serviceName);
	            }
	            else
	            {
		            if(isStartedInProcess())
		            {
		                response = ((MAXActionServiceLocal)ejbObject).wsSecureAction(req,
		                		serviceName);
		            }
		            else
		            {
		                response = ((MAXActionServiceRemote)ejbObject).secureAction(req,
		                		serviceName);
		            }
	            }
        	}
        }
        else
        {
            if(loginid != null && password != null)
            {
            	if(loginid.equals(SecurityUtil.APIKEYLOGIN))
            	{
            		String apikey = password;
            		WebMethodService service = new WebMethodService();
            		response = service.wsMaxAPIKeySecureAction(apikey, req, serviceName);
            	}
            	else
            	{
	                getLogger().debug("ActionWebServiceProvider - using maximo authentication info with loginid "+loginid);
	
	                if(isStartedInProcess())
	                {
	                    response = ((MAXActionServiceLocal)ejbObject).wsMaxSecureAction(loginid,password,req,
	                    		serviceName);
	                }
	                else
	                {
	                    response = ((MAXActionServiceRemote)ejbObject).wsMaxSecureAction(loginid,password,req,
	                    		serviceName);
	                }
            	}
            }
            else
            {
                getLogger().debug("ActionWebServiceProvider - using default authentication");

                if(isStartedInProcess())
                {
                    response = ((MAXActionServiceLocal)ejbObject).wsAction(req,
                    		serviceName);
                }
                else
                {
                    response = ((MAXActionServiceRemote)ejbObject).wsAction(req,
                    		serviceName);
                }
            }
        }
        return response;


	}

}
